@@ -364,9 +364,9 @@ exec_extension_view (void *target, char *cmd, const vfs_path_t * filename_vpath,
         changed_nroff_flag = 1;
 
     if (target == NULL)
-        mcview_viewer (cmd, filename_vpath, start_line);
+        mcview_viewer (cmd, filename_vpath, start_line, 0, 0);
     else
-        mcview_load ((mcview_t *) target, cmd, vfs_path_as_str (filename_vpath), start_line);
+        mcview_load ((WView *) target, cmd, vfs_path_as_str (filename_vpath), start_line, 0, 0);
 
     if (changed_hex_mode && !mcview_altered_hex_mode)
         mcview_default_hex_mode = def_hex_mode;
@@ -965,7 +965,7 @@ regex_command_for (void *target, const vfs_path_t * filename_vpath, const char *
                     p += 2;
 
                 found = regex_check_type (filename_vpath, p, case_insense, &have_type, &mcerror);
-                if (mc_error_message (&mcerror))
+                if (mc_error_message (&mcerror, NULL))
                     error_flag = TRUE;  /* leave it if file cannot be opened */
             }
             else if (strncmp (p, "default/", 8) == 0)
