@@ -47,7 +47,6 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <signal.h>
-#include <fcntl.h>
 #include <errno.h>
 #include <sys/wait.h>
 
@@ -67,8 +66,6 @@
 
 /*** global variables ****************************************************************************/
 
-GArray *extfs_plugins = NULL;
-
 /*** file scope macro definitions ****************************************************************/
 
 #undef ERRNOR
@@ -136,6 +133,8 @@ typedef struct
 
 /*** file scope variables ************************************************************************/
 
+static GArray *extfs_plugins = NULL;
+
 static gboolean errloop;
 static gboolean notadir;
 
@@ -1062,7 +1061,6 @@ extfs_readdir (void *data)
 
     g_strlcpy (dir.dent.d_name, (*info)->name, MC_MAXPATHLEN);
 
-    compute_namelen (&dir.dent);
     *info = (*info)->next_in_dir;
 
     return (void *) &dir;
