@@ -204,7 +204,7 @@
 /* TODO: These methods shouldn't be necessary, see ticket 3257 */
 
 static int
-mcview_wcwidth (const mcview_t * view, int c)
+mcview_wcwidth (const WView * view, int c)
 {
 #ifdef HAVE_CHARSET
     if (view->utf8)
@@ -224,7 +224,7 @@ mcview_wcwidth (const mcview_t * view, int c)
 /* --------------------------------------------------------------------------------------------- */
 
 static gboolean
-mcview_ismark (const mcview_t * view, int c)
+mcview_ismark (const WView * view, int c)
 {
 #ifdef HAVE_CHARSET
     if (view->utf8)
@@ -240,7 +240,7 @@ mcview_ismark (const mcview_t * view, int c)
 
 /* actually is_non_spacing_mark_or_enclosing_mark */
 static gboolean
-mcview_is_non_spacing_mark (const mcview_t * view, int c)
+mcview_is_non_spacing_mark (const WView * view, int c)
 {
 #ifdef HAVE_CHARSET
     if (view->utf8)
@@ -262,7 +262,7 @@ mcview_is_non_spacing_mark (const mcview_t * view, int c)
 
 #if 0
 static gboolean
-mcview_is_spacing_mark (const mcview_t * view, int c)
+mcview_is_spacing_mark (const WView * view, int c)
 {
 #ifdef HAVE_CHARSET
     if (view->utf8)
@@ -278,7 +278,7 @@ mcview_is_spacing_mark (const mcview_t * view, int c)
 /* --------------------------------------------------------------------------------------------- */
 
 static gboolean
-mcview_isprint (const mcview_t * view, int c)
+mcview_isprint (const WView * view, int c)
 {
 #ifdef HAVE_CHARSET
     if (!view->utf8)
@@ -286,15 +286,15 @@ mcview_isprint (const mcview_t * view, int c)
     return g_unichar_isprint (c);
 #else
     (void) view;
-#endif /* HAVE_CHARSET */
     /* TODO this is very-very buggy by design: ticket 3257 comments 0-1 */
     return is_printable (c);
+#endif /* HAVE_CHARSET */
 }
 
 /* --------------------------------------------------------------------------------------------- */
 
 static int
-mcview_char_display (const mcview_t * view, int c, char *s)
+mcview_char_display (const WView * view, int c, char *s)
 {
 #ifdef HAVE_CHARSET
     if (mc_global.utf8_display)
@@ -345,7 +345,7 @@ mcview_char_display (const mcview_t * view, int c, char *s)
  * TODO: move it to lower layers (datasource.c)?
  */
 static gboolean
-mcview_get_next_char (mcview_t * view, mcview_state_machine_t * state, int *c)
+mcview_get_next_char (WView * view, mcview_state_machine_t * state, int *c)
 {
     /* Pretend EOF if we reached force_max */
     if (view->force_max >= 0 && state->offset >= view->force_max)
@@ -394,8 +394,7 @@ mcview_get_next_char (mcview_t * view, mcview_state_machine_t * state, int *c)
  * color can be null if the caller doesn't care.
  */
 static gboolean
-mcview_get_next_maybe_nroff_char (mcview_t * view, mcview_state_machine_t * state, int *c,
-                                  int *color)
+mcview_get_next_maybe_nroff_char (WView * view, mcview_state_machine_t * state, int *c, int *color)
 {
     mcview_state_machine_t state_after_nroff;
     int c2, c3;
@@ -478,7 +477,7 @@ mcview_get_next_maybe_nroff_char (mcview_t * view, mcview_state_machine_t * stat
  * @return the number of entries placed in cs, or 0 on EOF
  */
 static int
-mcview_next_combining_char_sequence (mcview_t * view, mcview_state_machine_t * state, int *cs,
+mcview_next_combining_char_sequence (WView * view, mcview_state_machine_t * state, int *cs,
                                      int clen, int *color)
 {
     int i = 1;
@@ -577,7 +576,7 @@ mcview_next_combining_char_sequence (mcview_t * view, mcview_state_machine_t * s
  * @return the number of rows, that is, 0 if we were already at EOF, otherwise 1
  */
 static int
-mcview_display_line (mcview_t * view, mcview_state_machine_t * state, int row,
+mcview_display_line (WView * view, mcview_state_machine_t * state, int row,
                      gboolean * paragraph_ended, off_t * linewidth)
 {
     const screen_dimen left = view->data_area.left;
@@ -772,7 +771,7 @@ mcview_display_line (mcview_t * view, mcview_state_machine_t * state, int row,
  *   viewport, it's not counted how many more lines the paragraph would occupy
  */
 static int
-mcview_display_paragraph (mcview_t * view, mcview_state_machine_t * state, int row)
+mcview_display_paragraph (WView * view, mcview_state_machine_t * state, int row)
 {
     const screen_dimen height = view->data_area.height;
     int lines = 0;
@@ -809,7 +808,7 @@ mcview_display_paragraph (mcview_t * view, mcview_state_machine_t * state, int r
  * vertical position, in that case move to its last row.
  */
 static void
-mcview_wrap_fixup (mcview_t * view)
+mcview_wrap_fixup (WView * view)
 {
     int lines = view->dpy_paragraph_skip_lines;
 
@@ -853,7 +852,7 @@ mcview_wrap_fixup (mcview_t * view)
  * case dpy_state_top is invalid and we need to recompute first.
  */
 void
-mcview_display_text (mcview_t * view)
+mcview_display_text (WView * view)
 {
     const screen_dimen left = view->data_area.left;
     const screen_dimen top = view->data_area.top;
@@ -927,7 +926,7 @@ mcview_display_text (mcview_t * view)
  * the bottom of mcview_ascii_move_up()) which invalidate this value.
  */
 void
-mcview_ascii_move_down (mcview_t * view, off_t lines)
+mcview_ascii_move_down (WView * view, off_t lines)
 {
     while (lines-- != 0)
     {
@@ -976,7 +975,7 @@ mcview_ascii_move_down (mcview_t * view, off_t lines)
  * changes, we don't want to endlessly consume a file of maybe full of zeros upon moving upwards.
  */
 void
-mcview_ascii_move_up (mcview_t * view, off_t lines)
+mcview_ascii_move_up (WView * view, off_t lines)
 {
     if (!view->text_wrap_mode)
     {
@@ -1026,7 +1025,7 @@ mcview_ascii_move_up (mcview_t * view, off_t lines)
 /* --------------------------------------------------------------------------------------------- */
 
 void
-mcview_ascii_moveto_bol (mcview_t * view)
+mcview_ascii_moveto_bol (WView * view)
 {
     if (!view->text_wrap_mode)
         view->dpy_text_column = 0;
@@ -1035,7 +1034,7 @@ mcview_ascii_moveto_bol (mcview_t * view)
 /* --------------------------------------------------------------------------------------------- */
 
 void
-mcview_ascii_moveto_eol (mcview_t * view)
+mcview_ascii_moveto_eol (WView * view)
 {
     if (!view->text_wrap_mode)
     {
